@@ -278,7 +278,6 @@ class _StackSizeComputer:
             # an extra object on the stack.
 
         for i, instr in enumerate(self.block):
-
             # Ignore SetLineno
             if isinstance(instr, (SetLineno)):
                 continue
@@ -384,7 +383,6 @@ class _StackSizeComputer:
             # Instruction is final (return, raise, ...) so any following instruction
             # in the block is dead code.
             if instr.is_final():
-
                 # Check for TryEnd after the final instruction which is possible
                 # TryEnd being only pseudo instructions.
                 if te := self.block.get_trailing_try_end(i):
@@ -781,7 +779,6 @@ class ControlFlowGraph(_bytecode.BaseBytecode):
         try_begin_inserted_in_block = False
         last_instr: Optional[Instr] = None
         for index, instr in enumerate(bytecode):
-
             # Reference to the current block if we create a new one in the following.
             old_block: BasicBlock | None = None
 
@@ -822,14 +819,13 @@ class ControlFlowGraph(_bytecode.BaseBytecode):
             # - if the current instruction is a TryEnd and if the last instruction
             #   is final in which case we insert the TryEnd in the old block.
             # - if we have a currently active TryBegin for which we may need to
-            #   create a TryEnd in the previous and a new TryBegin in the new one
-            #   because the blocks are not connected.
+            #   create a TryEnd in the previous block and a new TryBegin in the
+            #   new one because the blocks are not connected.
             if old_block is not None:
                 temp = try_begin_inserted_in_block
                 try_begin_inserted_in_block = False
 
             if old_block is not None and last_instr is not None:
-
                 # The last instruction is final, if the current instruction is a
                 # TryEnd insert it in the same block and move to the next instruction
                 if last_instr.is_final() and isinstance(instr, TryEnd):
@@ -842,7 +838,6 @@ class ControlFlowGraph(_bytecode.BaseBytecode):
 
                 # If we have an active TryBegin and last_instr is:
                 elif active_try_begin is not None:
-
                     # - a jump whose target is beyond the TryEnd of the active
                     #   TryBegin: we remember TryEnd should be prepended to the
                     #   target block.
@@ -986,7 +981,8 @@ class ControlFlowGraph(_bytecode.BaseBytecode):
 
                         # If the TryBegin share the target and push_lasti of the
                         # entry of an adjacent TryEnd, omit the new TryBegin that
-                        # was inserted to allow analysis of the CFG
+                        # was inserted to allow analysis of the CFG and remove
+                        # the already inserted TryEnd.
                         if last_try_end is not None:
                             cfg_te, byt_te = last_try_end
                             entry = cfg_te.entry
@@ -994,10 +990,17 @@ class ControlFlowGraph(_bytecode.BaseBytecode):
                                 entry.target is instr.target
                                 and entry.push_lasti == instr.push_lasti
                             ):
-                                byt_te.entry.stack_depth = min(
-                                    entry.stack_depth, instr.stack_depth
-                                )
+                                # If we did not yet compute the required stack depth
+                                # keep the value as UNSET
+                                if entry.stack_depth is UNSET:
+                                    assert instr.stack_depth is UNSET
+                                    byt_te.entry.stack_depth = UNSET
+                                else:
+                                    byt_te.entry.stack_depth = min(
+                                        entry.stack_depth, instr.stack_depth
+                                    )
                                 try_begins[instr] = byt_te.entry
+                                instructions.remove(byt_te)
                                 continue
                         assert isinstance(new, TryBegin)
                         try_begins[instr] = new
